import customtkinter as ctk
from tkinter import filedialog, messagebox
import requests
import os

def create_product_frame(parent, switch_func, API_URL, token):
    """
    Frame to create a new product.
    Fields: Title, Price, Description, Stock, and Product Image.
    On success, navigates back to the shop view.
    """
    frame = ctk.CTkFrame(parent)
    title = ctk.CTkLabel(frame, text="Create New Product", font=("Helvetica", 18, "bold"))
    title.pack(pady=10)

    # Product Title
    prod_title_label = ctk.CTkLabel(frame, text="Product Title:")
    prod_title_label.pack(pady=5)
    prod_title_entry = ctk.CTkEntry(frame, width=300)
    prod_title_entry.pack(pady=5)

    # Price
    price_label = ctk.CTkLabel(frame, text="Price:")
    price_label.pack(pady=5)
    price_entry = ctk.CTkEntry(frame, width=300)
    price_entry.pack(pady=5)

    # Description
    desc_label = ctk.CTkLabel(frame, text="Description:")
    desc_label.pack(pady=5)
    desc_entry = ctk.CTkEntry(frame, width=300)
    desc_entry.pack(pady=5)

    # Stock Quantity
    stock_label = ctk.CTkLabel(frame, text="Stock Quantity:")
    stock_label.pack(pady=5)
    stock_entry = ctk.CTkEntry(frame, width=300)
    stock_entry.pack(pady=5)

    # Product Image Upload
    image_path = ctk.StringVar(value="No file selected")
    def browse_image():
        filename = filedialog.askopenfilename(
            title="Select Product Image", 
            filetypes=[("Image Files", "*.png;*.jpg;*.jpeg;*.gif")]
        )
        if filename:
            image_path.set(filename)
    browse_button = ctk.CTkButton(frame, text="Browse Image", command=browse_image)
    browse_button.pack(pady=5)
    image_label = ctk.CTkLabel(frame, textvariable=image_path)
    image_label.pack(pady=5)

    def submit_product():
        title_val = prod_title_entry.get().strip()
        price_val = price_entry.get().strip()
        desc_val = desc_entry.get().strip()
        stock_val = stock_entry.get().strip()
        if not title_val or not price_val or not stock_val:
            messagebox.showerror("Error", "Title, Price, and Stock are required")
            return

        # In a real scenario, you would pass the shop_id from view_shop.
        # For now, use a placeholder shop_id (e.g., 1)
        data = {
            "name": title_val,
            "price": price_val,
            "description": desc_val,
            "stock": stock_val,
            "shop_id": 1  # Replace with the actual shop id
        }
        files = {}
        if os.path.isfile(image_path.get()):
            files["images"] = open(image_path.get(), "rb")
        headers = {"Authorization": f"Bearer {token}"}
        try:
            resp = requests.post(f"{API_URL}/product/create", data=data, files=files, headers=headers)
            if resp.status_code == 200:
                messagebox.showinfo("Success", "Product created successfully!")
                switch_func("view_shop")  # You might pass shop data if needed
            else:
                messagebox.showerror("Error", f"Failed to create product. Status: {resp.status_code}\n{resp.text}")
        except Exception as e:
            messagebox.showerror("Error", f"Request error: {e}")
        finally:
            if files:
                files["images"].close()

    submit_button = ctk.CTkButton(frame, text="Create Product", command=submit_product)
    submit_button.pack(pady=10)

    return frame
