import customtkinter as ctk
from tkinter import filedialog, messagebox
import requests
import os

def create_shop_frame(parent, switch_func, API_URL, token):
    """
    Frame for a user to create a shop.
    This version stores the token in the frame and provides an update_token method.
    """
    frame = ctk.CTkFrame(parent)
    
    # Store the initial token in the frame
    frame.token = token

    # Define an update_token method so the global token can be propagated.
    def update_token(new_token):
        frame.token = new_token
    frame.update_token = update_token

    title = ctk.CTkLabel(frame, text="Create Your Shop", font=("Helvetica", 18, "bold"))
    title.pack(pady=10)

    # Shop Name Field
    shop_name_label = ctk.CTkLabel(frame, text="Shop Name:")
    shop_name_label.pack(pady=5)
    shop_name_entry = ctk.CTkEntry(frame, width=300)
    shop_name_entry.pack(pady=5)

    # Address Field (using a default for demonstration)
    address_label = ctk.CTkLabel(frame, text="Address:")
    address_label.pack(pady=5)
    address_entry = ctk.CTkEntry(frame, width=300)
    address_entry.insert(0, "123 Main St")
    address_entry.pack(pady=5)

    # Shop Image Upload
    image_path = ctk.StringVar(value="No file selected")
    def browse_image():
        filename = filedialog.askopenfilename(
            title="Select Shop Image", 
            filetypes=[("Image Files", "*.png;*.jpg;*.jpeg;*.gif")]
        )
        if filename:
            image_path.set(filename)
    browse_button = ctk.CTkButton(frame, text="Browse Image", command=browse_image)
    browse_button.pack(pady=5)
    image_label = ctk.CTkLabel(frame, textvariable=image_path)
    image_label.pack(pady=5)

    def submit_shop():
        # Use the token stored in the frame
        current_token = frame.token
        if not current_token:
            messagebox.showerror("Error", "No access token found. Please log in again.")
            return

        name = shop_name_entry.get().strip()
        address = address_entry.get().strip()
        if not name or not address:
            messagebox.showerror("Error", "Please fill all fields.")
            return

        data = {
            "name": name,
            "address": address,
            "description": "Default shop description"
        }
        files = {}
        if os.path.isfile(image_path.get()):
            files["file"] = open(image_path.get(), "rb")
        headers = {"Authorization": f"Bearer {current_token}"}
        print("Creating shop with token:", current_token)
        try:
            resp = requests.post(f"{API_URL}/shops/create", data=data, files=files, headers=headers)
            if resp.status_code == 200:
                shop = resp.json()
                messagebox.showinfo("Success", "Shop created successfully!")
                switch_func("view_shop", shop)  # Pass the shop data to the view shop frame
            else:
                messagebox.showerror("Error", f"Failed to create shop. Status: {resp.status_code}\n{resp.text}")
        except Exception as e:
            messagebox.showerror("Error", f"Request error: {e}")
        finally:
            if files:
                files["file"].close()

    submit_button = ctk.CTkButton(frame, text="Create Shop", command=submit_shop)
    submit_button.pack(pady=10)

    return frame
