import customtkinter as ctk
import requests
from PIL import Image, ImageTk
from tkinter import messagebox
import io

def view_shop_frame(parent, switch_func, shop_data, token, API_URL):
    """
    Frame to display the owner’s shop.
    If shop_data is None, display a message that no shop has been created.
    Otherwise, display the shop's details and its products.
    """
    frame = ctk.CTkFrame(parent)

    # If shop_data is None, show a message and a button to create a shop.
    if shop_data is None:
        msg = ctk.CTkLabel(frame, text="No shop created yet.", font=("Helvetica", 16, "bold"))
        msg.pack(pady=20)
        create_button = ctk.CTkButton(frame, text="Create Shop", command=lambda: switch_func("create_shop"))
        create_button.pack(pady=10)
        return frame

    # Otherwise, proceed normally.
    shop_name = shop_data.get("name", "No Name")
    shop_image_url = shop_data.get("image_url", "")

    # Header: Shop Image and Name
    header_frame = ctk.CTkFrame(frame)
    header_frame.pack(pady=10, fill="x")

    image_label = ctk.CTkLabel(header_frame, text="")
    image_label.pack(side="left", padx=10)
    try:
        resp = requests.get(shop_image_url)
        if resp.status_code == 200:
            pil_img = Image.open(io.BytesIO(resp.content)).resize((80, 80))
            tk_img = ImageTk.PhotoImage(pil_img)
            image_label.configure(image=tk_img, text="")
            image_label.image = tk_img
    except Exception as e:
        print("Error loading shop image:", e)
    name_label = ctk.CTkLabel(header_frame, text=shop_name, font=("Helvetica", 16, "bold"))
    name_label.pack(side="left", padx=10)

    # Button to create a new product
    def goto_create_product():
        switch_func("create_product", shop_data)
    create_prod_button = ctk.CTkButton(frame, text="Add New Product", command=goto_create_product)
    create_prod_button.pack(pady=10)

    # Products list
    products_frame = ctk.CTkScrollableFrame(frame, width=750, height=300)
    products_frame.pack(padx=10, pady=10, fill="both", expand=True)

    headers = {"Authorization": f"Bearer {token}"}
    try:
        resp = requests.get(f"{API_URL}/product/list?shop_id={shop_data.get('id')}", headers=headers)
        if resp.status_code == 200:
            products = resp.json()
            if products:
                for product in products:
                    prod_frame = ctk.CTkFrame(products_frame, fg_color="#2b2b2b", corner_radius=5)
                    prod_frame.pack(padx=5, pady=5, fill="x")
                    prod_name = product.get("name", "No Name")
                    prod_label = ctk.CTkLabel(prod_frame, text=prod_name, font=("Helvetica", 12, "bold"))
                    prod_label.pack(side="left", padx=10)
                    # Optionally, add more product details here
            else:
                ctk.CTkLabel(products_frame, text="No products found.").pack(pady=10)
        else:
            messagebox.showerror("Error", f"Failed to fetch products. Status: {resp.status_code}")
    except Exception as e:
        messagebox.showerror("Error", f"Request error: {e}")

    return frame
